==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/configdefs/playerconfigwidget.h <==
#ifndef PLAYERCONFIGWIDGET_H
#define PLAYERCONFIGWIDGET_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <appconfiggroupwidget.h>

class QLabel;
class QCheckBox;
class KComboBox;
class KFontCombo;
class KColorCombo;
class KIntNumInput;

namespace SubtitleComposer
{
	class PlayerConfigWidget : public AppConfigGroupWidget
	{
		Q_OBJECT

		public:

			PlayerConfigWidget( const AppConfigGroup& configGroup, QWidget* parent=0 );
			~PlayerConfigWidget();

			virtual void setControlsFromConfig();
			virtual void setConfigFromControls();

		private slots:

			void onFamilyChanged( const QString& family );
			void onSizeChanged( int size );
			void onColorChanged( const QColor& color );

		private:

			KComboBox* m_playerBackendComboBox;
			KIntNumInput* m_seekJumpSecsSpinBox;

			KFontCombo* m_fontComboBox;
			KIntNumInput* m_sizeSpinBox;
			KColorCombo* m_colorComboBox;

			QLabel* m_previewLabel;
	};
}

#endif

==> subtitlecomposer-0.4.2.tar.bz2: subtitlecomposer-0.4.2/src/main/configdefs/playerconfigwidget.h <==
#ifndef PLAYERCONFIGWIDGET_H
#define PLAYERCONFIGWIDGET_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <appconfiggroupwidget.h>

class QCheckBox;
class KComboBox;
class KFontCombo;
class KColorCombo;
class KIntNumInput;
class TextOverlayWidget;

namespace SubtitleComposer
{
	class PlayerConfigWidget : public AppConfigGroupWidget
	{
		Q_OBJECT

		public:

			PlayerConfigWidget( const AppConfigGroup& configGroup, QWidget* parent=0 );
			~PlayerConfigWidget();

			virtual void setControlsFromConfig();
			virtual void setConfigFromControls();

		private slots:

			void onFamilyChanged( const QString& family );
			void onSizeChanged( int size );
			void onPrimaryColorChanged( const QColor& color );
			void onOutlineColorChanged( const QColor& color );
			void onOutlineWidthChanged( int width );

		private:

			KComboBox* m_playerBackendComboBox;
			KIntNumInput* m_seekJumpSecsSpinBox;

			KFontCombo* m_fontComboBox;
			KIntNumInput* m_sizeSpinBox;
			KColorCombo* m_primaryColorComboBox;
			KColorCombo* m_outlineColorComboBox;
			KIntNumInput* m_outlineWidthSpinBox;
			TextOverlayWidget* m_textOverlayWidget;
	};
}

#endif
